Documentation
¶
Index ¶
Constants ¶
const ( // BestSpeed provides speed over better compression. BestSpeed = 3 // BestCompression provides better compression over speed. BestCompression = 9 )
Variables ¶
This section is empty.
Functions ¶
func CreateIndex ¶
Types ¶
type Header ¶
Header metadata about the compressed file. This header is exposed as the fields of the Writer and Reader structs.
type IndexHeader ¶
Header metadata about the compressed file. This header is exposed as the fields of the Writer and Reader structs.
type Indexer ¶
type Indexer struct {
IndexHeader
// contains filtered or unexported fields
}
A Reader is an io.Reader that can be read to retrieve uncompressed data from a lzop-format compressed file.
func NewIndexer ¶
NewReader creates a new Reader reading the given reader.
type Reader ¶
type Reader struct {
Header
// contains filtered or unexported fields
}
A Reader is an io.Reader that can be read to retrieve uncompressed data from a lzop-format compressed file.
type Writer ¶
type Writer struct {
Header
// contains filtered or unexported fields
}
A Writer is an io.Write that satisfies writes by compressing data written to its wrapped io.Writer.
func NewWriter ¶
NewWriter creates a new Writer that satisfies writes by compressing data written to w.
func NewWriterLevel ¶
NewWriterLevel is like NewWriter but specifies the compression level instead of assuming DefaultCompression.